@@ -16,7 +16,7 @@ CREATE OR REPLACE FUNCTION pgl_ddl_deploy.subscriber_command
   p_run_anywhere BOOLEAN = FALSE
 )
 RETURNS BOOLEAN
-AS $pgl_ddl_deploy_sql$
+AS $function$
 /****
 This function is what will actually be executed on the subscriber when attempting to apply DDL
 changed.  It is sent to subscriber(s) via pglogical.replicate_ddl_command.  You can see how it
@@ -160,5 +160,5 @@ END IF;
 RETURN v_succeeded;
 
 END;
-$pgl_ddl_deploy_sql$
+$function$
 LANGUAGE plpgsql VOLATILE;
